.. _guilty:


.. raw:: html

    <br>

.. title:: Guilty


.. _informed:


**INFORMED**


.. image:: informed.jpg
    :height: 8cm

.. raw:: html

    <br>

.. _chamber:

**CHAMBER**

.. image:: kamer.png


.. raw:: html

    <br>

.. _king:


**KING**


.. image:: bevestigd.jpg

.. raw:: html

  <br>
